durtools.yield_all_positive_rationals_in_cantor_diagonalized_order
==================================================================

.. autofunction:: abjad.tools.durtools.yield_all_positive_rationals_in_cantor_diagonalized_order
